@@ -5,8 +5,8 @@ try:
 except ImportError:
     pass
 
-jqueryui = Library('jqueryui')
+jqueryui_lib = Library('jqueryui', 'jqueryui-build')
 
-jqueryui = ResourceInclusion(jqueryui, 'jquery-ui.js', depends=[jquery],
+jqueryui = ResourceInclusion(jqueryui_lib, 'jquery-ui.js', depends=[jquery],
                              minified='jquery-ui.min.js')
 
